@@ -16,8 +16,8 @@ class StrategyDemo(StrategyTemplate):
     binance_api_setting = {
         "key": "",
         "secret": "",
-        "proxy_host": "127.0.0.1",
-        "proxy_port": 8010,
+        "proxy_host": "",
+        "proxy_port": 0,
         "Passphrase": "",
 
         "call_order_switch": False,  # 订单数据回调 开关
@@ -28,8 +28,8 @@ class StrategyDemo(StrategyTemplate):
     okex_api_setting = {
         "key": "",
         "secret": "",
-        "proxy_host": "127.0.0.1",
-        "proxy_port": 8010,
+        "proxy_host": "",
+        "proxy_port": 0,
         "Passphrase": "",
 
         "call_order_switch": True,  # 订单数据回调 开关
@@ -47,8 +47,7 @@ class StrategyDemo(StrategyTemplate):
 
         self.buy_switch = True
         self.long_id = ""
-        self.stop_loss_id = ""
-        self.stop_profit_id = ""
+        self.stop_id = ""
         self.volume = 1
         self.rate_stop = 0.008
 
@@ -102,7 +101,7 @@ class StrategyDemo(StrategyTemplate):
             print(f"最新开盘价：{open_price}")
             self.stop_id = okex_api.new_order_id()
             okex_api.sell(
-                orderid=self.stop_profit_id,
+                orderid=self.stop_id,
                 symbol=self.symbol,
                 volume=self.volume,
                 price=round(open_price * (1 + self.rate_stop), 3),
