@@ -91,7 +91,8 @@ class BinanceFutureInverseGateway(BaseGateway):
     product: Product = Product.B_FUTURES
     symbolMap: dict = dict()
 
-    def __init__(self, event_engine: EventEngine, order_switch: bool = False, bar_switch: bool = False, tick_switch: bool = False) -> None:
+    def __init__(self, event_engine: EventEngine, order_switch: bool = False, bar_switch: bool = False,
+                 tick_switch: bool = False) -> None:
         """init"""
         super().__init__(event_engine, order_switch, bar_switch, tick_switch)
         self.trade_ws_api: "BinanceInverseTradeWebsocketApi" = BinanceInverseTradeWebsocketApi(self)
@@ -116,8 +117,14 @@ class BinanceFutureInverseGateway(BaseGateway):
         self.rest_api.connect(key, secret, proxy_host, proxy_port)
         self.market_ws_api.connect(proxy_host, proxy_port)
 
-        self.event_engine.unregister(EVENT_TIMER, self.process_timer_event)
-        self.event_engine.register(EVENT_TIMER, self.process_timer_event)
+        if self.order_call_switch:
+            self.event_engine.unregister(EVENT_TIMER, self.process_timer_event)
+            self.event_engine.register(EVENT_TIMER, self.process_timer_event)
+            self.event_engine.unregister(EVENT_TIMER, self.trade_ws_api.ping_pong)
+            self.event_engine.register(EVENT_TIMER, self.trade_ws_api.ping_pong)
+
+        self.event_engine.unregister(EVENT_TIMER, self.market_ws_api.ping_pong)
+        self.event_engine.register(EVENT_TIMER, self.market_ws_api.ping_pong)
 
     # 定时任务, 不间断获取服务器时间
     def process_timer_event(self, event: Event) -> None:
@@ -391,8 +398,10 @@ class BinanceInverseRestApi(RestClient):
 
         # 获取服务器时间
         self.query_time()
+
         # 保持用户 ws 的链接
-        self.start_user_stream()
+        if self.gateway.order_call_switch:
+            self.start_user_stream()
 
     # 查询服务器时间
     def query_time(self) -> None:
@@ -732,15 +741,18 @@ class BinanceInverseRestApi(RestClient):
 
     # 开始获取ws stream 失败处理
     def on_start_user_stream_failed(self, status_code: int, request: Request):
+        print("binance 获取 start_user_stream 失败，重新获取")
         self.failed_with_timestamp(request)  # 重新获取服务器时间撮
         self.start_user_stream()  # 再次链接
 
     # 开始获取ws stream 错误处理
     def on_start_user_stream_error(self, exception_type: type, exception_value: Exception, tb, request: Request):
+        print("binance 获取 start_user_stream 错误，重新获取")
         self.start_user_stream()  # 再次链接
 
     # 延长监听密钥过期时间请求回调
     def on_keep_user_stream(self, data: dict, request: Request) -> None:
+        print("binance 保持 start_user_stream 成功")
         self.keep_alive_failed_count = 0
 
     # 延长监听密钥过期失败回处理
@@ -748,9 +760,11 @@ class BinanceInverseRestApi(RestClient):
         self.failed_with_timestamp(request)
         self.keep_alive_failed_count += 1
         if self.keep_alive_failed_count <= 3:
+            print("binance 保持 start_user_stream 失败，重新 发送延长 请求")
             self.keep_alive_count = 1200000
             self.keep_user_stream()
         else:
+            print("binance 保持 start_user_stream 失败 次数过多，重新获取，链接交易ws")
             self.keep_alive_failed_count = 0
             self.start_user_stream()
 
@@ -758,6 +772,7 @@ class BinanceInverseRestApi(RestClient):
     def on_keep_user_stream_error(
             self, exception_type: type, exception_value: Exception, tb, request: Request
     ) -> None:
+        print("binance 保持 start_user_stream 出现错误，重新获取")
         self.keep_alive_failed_count += 1
         if self.keep_alive_failed_count <= 3:
             self.keep_alive_count = 1200000
@@ -787,6 +802,9 @@ class BinanceInverseTradeWebsocketApi(WebsocketClient):
 
         self.gateway: BinanceFutureInverseGateway = gateway
 
+        self.ping_max_num = 4 * 60
+        self.ping_count = 0
+
     def connect(self, url: str, proxy_host: str, proxy_port: int) -> None:
         """连接 binance usdt/busd 期货交易 ws"""
         self.init(url, proxy_host, proxy_port)
@@ -795,6 +813,13 @@ class BinanceInverseTradeWebsocketApi(WebsocketClient):
     def on_connected(self) -> None:
         pass
 
+    def ping_pong(self, event: Event) -> None:
+        if self.ping_count > self.ping_max_num:
+            self.send_packet(send_pong=True)
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def on_packet(self, packet: dict) -> None:
         """从 ws 接收数据s"""
         if packet["e"] == "ORDER_TRADE_UPDATE":
@@ -840,6 +865,9 @@ class BinanceInverseDataWebsocketApi(WebsocketClient):
         self.bars: Dict[str, BarData] = {}
         self.reqid: int = 0
 
+        self.ping_max_num = 4 * 60
+        self.ping_count = 0
+
     def connect(
             self,
             proxy_host: str,
@@ -849,6 +877,13 @@ class BinanceInverseDataWebsocketApi(WebsocketClient):
         self.init(F_WEBSOCKET_DATA_HOST, proxy_host, proxy_port)
         self.start()
 
+    def ping_pong(self, event: Event) -> None:
+        if self.ping_count > self.ping_max_num:
+            self.send_packet(send_pong=True)
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def on_connected(self) -> None:
         if self.ticks:
             channels = []
@@ -860,7 +895,7 @@ class BinanceInverseDataWebsocketApi(WebsocketClient):
                 "params": channels,
                 "id": self.reqid
             }
-            self.send_packet(req)
+            self.send_packet(packet=req)
 
     def subscribe(self, symbol: str, interval: Interval = None) -> None:
         """订阅数据"""
@@ -903,7 +938,7 @@ class BinanceInverseDataWebsocketApi(WebsocketClient):
             "params": channels,
             "id": self.reqid
         }
-        self.send_packet(req)
+        self.send_packet(packet=req)
 
     def on_packet(self, packet: dict):
         stream: str = packet.get("stream", None)
