@@ -116,8 +116,15 @@ class BinanceFutureUsdtGateway(BaseGateway):
         self.rest_api.connect(key, secret, proxy_host, proxy_port)
         self.market_ws_api.connect(proxy_host, proxy_port)
 
-        self.event_engine.unregister(EVENT_TIMER, self.process_timer_event)
-        self.event_engine.register(EVENT_TIMER, self.process_timer_event)
+        if self.order_call_switch:
+            self.event_engine.unregister(EVENT_TIMER, self.process_timer_event)
+            self.event_engine.register(EVENT_TIMER, self.process_timer_event)
+
+            self.event_engine.unregister(EVENT_TIMER, self.trade_ws_api.ping_pong)
+            self.event_engine.register(EVENT_TIMER, self.trade_ws_api.ping_pong)
+
+        self.event_engine.unregister(EVENT_TIMER, self.market_ws_api.ping_pong)
+        self.event_engine.register(EVENT_TIMER, self.market_ws_api.ping_pong)
 
     # 定时任务, 不间断获取服务器时间
     def process_timer_event(self, event: Event) -> None:
@@ -389,8 +396,9 @@ class BinanceUsdtRestApi(RestClient):
 
         # 获取服务器时间
         self.query_time()
-        # 保持用户 ws 的链接：订单回调
-        self.start_user_stream()
+        # 保持用户 ws 的链接
+        if self.gateway.order_call_switch:
+            self.start_user_stream()
 
     # 查询服务器时间
     def query_time(self) -> None:
@@ -725,15 +733,18 @@ class BinanceUsdtRestApi(RestClient):
 
     # 开始获取ws stream 失败处理
     def on_start_user_stream_failed(self, status_code: int, request: Request):
+        print("binance 获取 start_user_stream 失败，重新获取")
         self.failed_with_timestamp(request)  # 重新获取服务器时间撮
         self.start_user_stream()  # 再次链接
 
     # 开始获取ws stream 错误处理
     def on_start_user_stream_error(self, exception_type: type, exception_value: Exception, tb, request: Request):
+        print("binance 获取 start_user_stream 错误，重新获取")
         self.start_user_stream()  # 再次链接
 
     # 延长监听密钥过期时间请求回调
     def on_keep_user_stream(self, data: dict, request: Request) -> None:
+        print("binance 保持 start_user_stream 成功")
         self.keep_alive_failed_count = 0
 
     # 延长监听密钥过期失败回处理
@@ -741,9 +752,11 @@ class BinanceUsdtRestApi(RestClient):
         self.failed_with_timestamp(request)
         self.keep_alive_failed_count += 1
         if self.keep_alive_failed_count <= 3:
+            print("binance 保持 start_user_stream 失败，重新 发送延长 请求")
             self.keep_alive_count = 1200000
             self.keep_user_stream()
         else:
+            print("binance 保持 start_user_stream 失败 次数过多，重新获取，链接交易ws")
             self.keep_alive_failed_count = 0
             self.start_user_stream()
 
@@ -751,6 +764,7 @@ class BinanceUsdtRestApi(RestClient):
     def on_keep_user_stream_error(
             self, exception_type: type, exception_value: Exception, tb, request: Request
     ) -> None:
+        print("binance 保持 start_user_stream 出现错误，重新获取")
         self.keep_alive_failed_count += 1
         if self.keep_alive_failed_count <= 3:
             self.keep_alive_count = 1200000
@@ -779,12 +793,21 @@ class BinanceUsdtTradeWebsocketApi(WebsocketClient):
         super().__init__()
 
         self.gateway: BinanceFutureUsdtGateway = gateway
+        self.ping_max_num = 4 * 60
+        self.ping_count = 0
 
     def connect(self, url: str, proxy_host: str, proxy_port: int) -> None:
         """连接 binance usdt/busd 期货交易 ws"""
         self.init(url, proxy_host, proxy_port)
         self.start()
 
+    def ping_pong(self, event: Event):
+        if self.ping_count > self.ping_max_num:
+            self.send_packet(send_pong=True)
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def on_connected(self) -> None:
         pass
 
@@ -833,6 +856,9 @@ class BinanceUsdtDataWebsocketApi(WebsocketClient):
         self.bars: Dict[str, BarData] = {}
         self.reqid: int = 0
 
+        self.ping_max_num = 4 * 60
+        self.ping_count = 0
+
     def connect(
             self,
             proxy_host: str,
@@ -842,6 +868,13 @@ class BinanceUsdtDataWebsocketApi(WebsocketClient):
         self.init(F_WEBSOCKET_DATA_HOST, proxy_host, proxy_port)
         self.start()
 
+    def ping_pong(self, event: Event):
+        if self.ping_count > self.ping_max_num:
+            self.send_packet(send_pong=True)
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def on_connected(self) -> None:
         channels = []
         for target in self.bars:
@@ -856,7 +889,7 @@ class BinanceUsdtDataWebsocketApi(WebsocketClient):
                 "params": channels,
                 "id": self.reqid
             }
-            self.send_packet(req)
+            self.send_packet(packet=req)
 
     def subscribe(self, symbol: str, interval: Interval = None) -> None:
         """订阅数据"""
@@ -898,7 +931,7 @@ class BinanceUsdtDataWebsocketApi(WebsocketClient):
             "params": [target],
             "id": self.reqid
         }
-        self.send_packet(req)
+        self.send_packet(packet=req)
 
     def on_packet(self, packet: dict):
         stream: str = packet.get("stream", None)
