@@ -126,17 +126,17 @@ class OkexFutureUsdtGateway(BaseGateway):
             proxy_host,
             proxy_port
         )
+        if self.order_call_switch:
+            self.trade_ws_api.connect(
+                key,
+                secret,
+                passphrase,
+                proxy_host,
+                proxy_port,
+            )
 
-        self.trade_ws_api.connect(
-            key,
-            secret,
-            passphrase,
-            proxy_host,
-            proxy_port,
-        )
-
-        self.event_engine.unregister(EVENT_TIMER, self.trade_ws_api.ping_pong)
-        self.event_engine.register(EVENT_TIMER, self.trade_ws_api.ping_pong)
+            self.event_engine.unregister(EVENT_TIMER, self.trade_ws_api.ping_pong)
+            self.event_engine.register(EVENT_TIMER, self.trade_ws_api.ping_pong)
 
         self.event_engine.unregister(EVENT_TIMER, self.market_ws_api.ping_pong)
         self.event_engine.register(EVENT_TIMER, self.market_ws_api.ping_pong)
@@ -647,13 +647,14 @@ class OkexWebsocketPublicApi(WebsocketClient):
 
     def ping_pong(self, event: Event) -> None:
         if self.ping_count > self.ping_max_num:
-            self.send_packet("ping")
+            self.send_packet(packet="ping")
             self.ping_count = 0
         else:
             self.ping_count += 1
 
     def subscribe(self, symbol: str, interval: Interval = None) -> None:
         """订阅行情"""
+        print("订阅行情")
         if interval:
             target = symbol + f"*{interval.value}"
             if target in self.bars:
@@ -688,40 +689,38 @@ class OkexWebsocketPublicApi(WebsocketClient):
             "op": "subscribe",
             "args": args
         }
-        self.send_packet(req)
+        self.send_packet(packet=req)
 
     def on_connected(self) -> None:
         """连接成功回报"""
-        if self.ping_count > self.ping_max_num:
-            args = []
-            for target in self.bars:
-                symbol, interval = target.split("*")
-                d = {"channel": f"candle{interval}", "instId": symbol}
-                args.append(d)
-            for target in self.ticks:
-                d = {"channel": "tickers", "instId": target}
-                args.append(d)
-            if args:
-                req: dict = {
-                    "op": "subscribe",
-                    "args": args
-                }
-                self.send_packet(req)
-            print("Okex Websocket Public API连接成功, 重新订阅")
-        else:
-            print("Okex Websocket Public API连接成功, 没有重新订阅")
+        args = []
+        for target in self.bars:
+            symbol, interval = target.split("*")
+            d = {"channel": f"candle{interval}", "instId": symbol}
+            args.append(d)
+        for target in self.ticks:
+            d = {"channel": "tickers", "instId": target}
+            args.append(d)
+        if args:
+            req: dict = {
+                "op": "subscribe",
+                "args": args
+            }
+            self.send_packet(packet=req)
+        print("Okex Websocket Public API连接成功, 重新订阅")
 
     def on_disconnected(self) -> None:
         """连接断开回报"""
-        pass
-        # print("Okex Websocket Public API连接断开")
+        print("Okex Websocket Public API连接断开")
 
     def on_packet(self, packet: dict) -> None:
         """推送数据回报"""
-        print(packet)
 
         self.ping_count = 0
 
+        if packet == "pong":
+            return
+
         if "event" in packet:
             event: str = packet["event"]
             if event == "subscribe":
@@ -777,7 +776,7 @@ class OkexWebsocketPrivateApi(WebsocketClient):
         self.key: str = ""
         self.secret: str = ""
         self.passphrase: str = ""
-
+        self.login_tag: bool = False
         self.reqid: int = 0
         self.order_count: int = 0
         self.connect_time: int = 0
@@ -812,28 +811,27 @@ class OkexWebsocketPrivateApi(WebsocketClient):
 
     def ping_pong(self, event: Event) -> None:
         if self.ping_count > self.ping_max_num:
-            self.send_packet("ping")
+            self.send_packet(packet="ping")
             self.ping_count = 0
         else:
             self.ping_count += 1
 
     def on_connected(self) -> None:
         """连接成功回报"""
-        if self.ping_count > self.ping_max_num:
-            self.login()
-            print("私有频道链接成功，重新登陆")
-        else:
-            print("私有频道链接成功，没有重新登陆")
+        self.login_tag = True
+        self.login()
+        print("私有频道链接成功，重新登陆")
 
     def on_disconnected(self) -> None:
         """连接断开回报"""
+        print("Websocket 私有频道 API连接断开")
         pass
-        # print("Websocket Private API连接断开")
 
     def on_packet(self, packet: dict) -> None:
         """推送数据回报"""
-        print(packet)
         self.ping_count = 0
+        if packet == "pong":
+            return
 
         if "event" in packet:
             cb_name: str = packet["event"]
@@ -863,6 +861,7 @@ class OkexWebsocketPrivateApi(WebsocketClient):
             print("重新登陆成功，重新订阅 订单数据")
             self.subscribe_topic()
         else:
+            self.login_tag = False
             print("Websocket Private API登录失败")
 
     def login(self) -> None:
@@ -883,7 +882,7 @@ class OkexWebsocketPrivateApi(WebsocketClient):
                     }
                 ]
         }
-        self.send_packet(okex_req)
+        self.send_packet(packet=okex_req)
 
     def on_order(self, packet: dict) -> None:
         """委托更新推送"""
@@ -907,7 +906,7 @@ class OkexWebsocketPrivateApi(WebsocketClient):
                 },
             ]
         }
-        self.send_packet(okex_req)
+        self.send_packet(packet=okex_req)
 
 
 def generate_datetime(timestamp: str) -> datetime:
@@ -945,8 +944,10 @@ def parse_order_data(data: dict) -> OrderData:
         datetime=generate_datetime(data["cTime"]),
         status=STATUS_OKEX2VT[data["state"]],
     )
-    # if data['px'] != "":
-    #     order.price = float(data['px'])
-    # else:
-    #     order.price = None
+    stop_way = data.get("actualSide")
+    if stop_way:
+        if stop_way == "sl":
+            order.type = OrderType.STOP_MARKET
+        else:
+            order.type = OrderType.TAKE_PROFIT_MARKET
     return order
