@@ -35,7 +35,9 @@ class BaseGateway(ABC):
             price: float = 0,  # 价格
             maker: bool = False,  # 限价单
             stop_loss: bool = False,  # 止损
+            stop_loss_price: float = 0,  # 止损价
             stop_profit: bool = False,  # 止盈
+            stop_profit_price: float = 0,  # 止盈价
             position_side: PositionSide = PositionSide.ONEWAY,
             ):
         pass
@@ -47,7 +49,9 @@ class BaseGateway(ABC):
              price: float = 0,  # 价格
              maker: bool = False,  # 限价单
              stop_loss: bool = False,  # 止损
+             stop_loss_price: float = 0,  # 止损价
              stop_profit: bool = False,  # 止盈
+             stop_profit_price: float = 0,  # 止盈价
              position_side: PositionSide = PositionSide.ONEWAY,
              ):
         pass
@@ -59,7 +63,9 @@ class BaseGateway(ABC):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         pass
@@ -71,7 +77,9 @@ class BaseGateway(ABC):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         pass
