@@ -22,11 +22,16 @@ def symbol_deal(symbol: str, exchange: Exchange) -> str:
         return ""
 
 
-def get_order_type(maker: bool = False, stop_loss: bool = False, stop_profit: bool = False) -> OrderType:
+def get_order_type(maker: bool, stop_loss: bool, stop_profit: bool, exchange: Exchange) -> OrderType:
     if maker:
         # 发送限价单
         order_type = OrderType.LIMIT
     else:
+        if stop_profit and stop_loss:
+            if exchange == Exchange.BINANCE:
+                raise ValueError("BINANCE cannot combine stop loss and take profit orders")
+            order_type = OrderType.STOP_LOSS_PROFIT
+            return order_type
         if stop_profit:
             # 发送市价止盈
             order_type = OrderType.TAKE_PROFIT_MARKET
